Index: apps/app_amd.c
===================================================================
--- apps/app_amd.c	(revision 128561)
+++ apps/app_amd.c	(working copy)
@@ -39,8 +39,80 @@
 #include "asterisk/config.h"
 #include "asterisk/app.h"
 
+/*** DOCUMENTATION
+	<application name="AMD">
+		<synopsis>
+			Attempt to detect answering machines
+		</synopsis>
+		<description>
+			This application attempts to detect answering machines at the beginning
+			of outbound calls. Simply call this application after the call
+			has been answered (outbound only, of course).
+			When loaded, AMD reads amd.conf and uses the parameters specified as
+			default values. Those default values get overwritten when the calling AMD
+			with parameters.
+		</description>
+		<variable name="AMDSTATUS">
+			This is the status of the answering machine detection
+			<value name="MACHINE" />
+			<value name="HUMAN" />
+			<value name="NOTSURE" />
+			<value name="HANGUP" />
+		</variable>
+		<variable name="AMDCAUSE">
+			Indicates the cause that led to the conclusion
+			<value name="TOOLONG">
+				Total Time
+			</value>
+			<value name="INITIALSILENCE">
+				Silence Duration - Initial Silence
+			</value>
+			<value name="HUMAN">
+				Silence Duration - afterGreetingSilence
+			</value>
+			<value name="LONGGREETING">
+				Voice Duration - Greeting
+			</value>
+			<value name="MAXWORDLENGTH">
+				Word Count - maximum number of words
+			</value>	
+		<option name="initialSilence">
+			Is maximum initial silence duration before greeting.
+			If this is exceeded set as MACHINE
+		</option>
+		<option name="greeting">
+			is the maximum length of a greeting.
+			If this is exceeded set as MACHINE
+		<option name="afterGreetingSilence">
+			Is the silence after detecting a greeting.
+			If this is exceeded set as HUMAN
+		</option>
+		<option name="totalAnalysis Time">
+			Is the maximum time allowed for the algorithm
+			to decide HUMAN or MACHINE
+		</option>
+		<option name="miniumWordLength">
+			Is the minimum duration of Voice considered to be a word
+		</option>
+		<option name="betweenWordSilence">
+			Is the minimum duration of silence after a word to
+			consider the audio that follows to be a new word
+		</option>
+		<option name="maximumNumberOfWords">
+			Is the maximum number of words in a greeting
+			If this is exceeded set as MACHINE
+		<option name="silenceThreshold">
+			How long do we consider silence
+		</option>
+		<option name="maximumWordLength">
+			Is the maximum duration of a word to accept.
+			If exceeded set as MACHINE
+		</option>
+	</application>
 
+ ***/
 static char *app = "AMD";
+/*
 static char *synopsis = "Attempts to detect answering machines";
 static char *descrip =
 "  AMD([initialSilence],[greeting],[afterGreetingSilence],[totalAnalysisTime]\n"
@@ -78,7 +150,7 @@
 "               MAXWORDS-<%d wordsCount>-<%d maximumNumberOfWords>\n"
 "               LONGGREETING-<%d voiceDuration>-<%d greeting>\n"
 "               MAXWORDLENGTH-<%d consecutiveVoiceDuration>\n";
-
+*/
 #define STATE_IN_WORD       1
 #define STATE_IN_SILENCE    2
 
Index: apps/app_fax.c
===================================================================
--- apps/app_fax.c	(revision 128561)
+++ apps/app_fax.c	(working copy)
@@ -40,8 +40,55 @@
 #include "asterisk/module.h"
 #include "asterisk/manager.h"
 
+/*** DOCUMENTATION
+	<application name="SendFAX">
+		<synopsis>
+			Send a Fax
+		</synopsis>
+		<description>
+			Send a given TIFF file to the channel as a FAX.
+		</description>
+		<variable name="LOCALSTATIONID">
+			To identify itself to the remote end
+		</variable>
+		<variable name="LOCALHEADERINFO">
+			To generate a header line on each page
+		</variable>
+		<variable name="FAXSTATUS">
+			<value name="SUCCESS"/>
+			<value name="FAILED"/>
+		</variable>
+		<variable name="FAXERROR">
+			Cause of failure
+		</variable>
+		<variable name="REMOTESTATIONID">
+			The CSID of the remote side
+		</variable>
+		<variable name="FAXPAGES">
+			Number of pages sent
+		</variable>
+		<variable name="FAXBITRATE">
+			Transmission rate
+		</variable>
+		<variable name="FAXRESOLUTION">
+			Resolution of sent fax
+		</variable>
+		<option name="a">
+			Makes the application behave as the answering machine
+			(Default behavior is as calling machine)
+		</option>
+		<return name="0">
+			Success
+		</return>
+		<return name="1">
+			Failure
+		</return>
+	</application>
+ */
+
 static char *app_sndfax_name = "SendFAX";
 static char *app_sndfax_synopsis = "Send a FAX";
+/*
 static char *app_sndfax_desc = 
 "  SendFAX(filename[|options]):\n"
 "Send a given TIFF file to the channel as a FAX.\n"
@@ -64,9 +111,59 @@
 "\n"
 "Returns -1 in case of user hang up or any channel error.\n"
 "Returns 0 on success.\n";
+*/
 
+/*** DOCUMENTATION
+	<application name="ReceiveFAX">
+		<synopsis>
+			Receive a Fax
+		</synopsis>
+		<description>
+			Receives a FAX from the channel into the given filename
+			overwriting the file if it already exists.
+			File created will be in TIFF format.
+		</description>
+		<variable name="LOCALSTATIONID">
+			To identify itself to the remote end
+		</variable>
+		<variable name="LOCALHEADERINFO">
+			To generate a header line on each page
+		</variable>
+		<variable name="FAXSTATUS">
+			<value name="SUCCESS"/>
+			<value name="FAILED"/>
+		</variable>
+		<variable name="FAXERROR">
+			Cause of failure
+		</variable>
+		<variable name="REMOTESTATIONID">
+			The CSID of the remote side
+		</variable>
+		<variable name="FAXPAGES">
+			Number of pages sent
+		</variable>
+		<variable name="FAXBITRATE">
+			Transmission rate
+		</variable>
+		<variable name="FAXRESOLUTION">
+			Resolution of sent fax
+		</variable>
+		<option name="c">
+			Makes the application behave as the calling machine
+			(Default behavior is as answering machine)
+		</option>
+		<return name="0">
+			Success
+		</return>
+		<return name="-1">
+			Failure if user hangup or channel error
+		</return>
+	</application>
+ */
+
 static char *app_rcvfax_name = "ReceiveFAX";
 static char *app_rcvfax_synopsis = "Receive a FAX";
+/*
 static char *app_rcvfax_desc = 
 "  ReceiveFAX(filename[|options]):\n"
 "Receives a fax from the channel into the given filename overwriting\n"
@@ -90,7 +187,7 @@
 "\n"
 "Returns -1 in case of user hang up or any channel error.\n"
 "Returns 0 on success.\n";
-
+*/
 #define MAX_SAMPLES 240
 
 /* Watchdog. I have seen situations when remote fax disconnects (because of poor line
